@@ -11,19 +11,19 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-from zope.interface import implements
+from zope.interface import implementer
 from zope.authentication.interfaces import IAuthentication, PrincipalLookupError
 from zope.security.interfaces import IPrincipal
 
+
+@implementer(IAuthentication)
 class DummyPrincipalRegistry(object):
     """Dummy principal registry that only implements getPrincipal
     and definePrincipal method that are needed for securitypolicy tests."""
-    
-    implements(IAuthentication)
-    
+
     def __init__(self):
         self._principals = {}
-        
+
     def getPrincipal(self, id):
         if id not in self._principals:
             raise PrincipalLookupError(id)
@@ -36,11 +36,11 @@ class DummyPrincipalRegistry(object):
 
 principalRegistry = DummyPrincipalRegistry()
 
+
+@implementer(IPrincipal)
 class DummyPrincipal(object):
     """Very simple principal implementation"""
-    
-    implements(IPrincipal)
-    
+
     def __init__(self, id, title=u'', description=u''):
         self.id = id
         self.title = title
