@@ -17,7 +17,7 @@ import unittest
 
 from zope.component import provideAdapter, provideUtility
 from zope.component.testing import PlacelessSetup
-from zope.interface import implements
+from zope.interface import implementer
 from zope.annotation.attribute import AttributeAnnotations
 from zope.annotation.interfaces import IAttributeAnnotatable
 from zope.security.interfaces import IPermission
@@ -29,8 +29,10 @@ from zope.securitypolicy.principalpermission import \
 from zope.securitypolicy.tests import principalRegistry
 
 
+@implementer(IAttributeAnnotatable)
 class Manageable(object):
-    implements(IAttributeAnnotatable)
+    pass
+
 
 class Test(PlacelessSetup, unittest.TestCase):
 
@@ -112,7 +114,7 @@ class Test(PlacelessSetup, unittest.TestCase):
         manager = AnnotationPrincipalPermissionManager(Manageable())
         provideUtility(Permission('Perm One', 'title'), IPermission,
                        'Perm One')
-        perm1 = 'Perm One' 
+        perm1 = 'Perm One'
         provideUtility(Permission('Perm Two', 'title'), IPermission,
                        'Perm Two')
         perm2 = 'Perm Two'
@@ -121,31 +123,32 @@ class Test(PlacelessSetup, unittest.TestCase):
         manager.grantPermissionToPrincipal(perm2, prin1)
         perms = manager.getPermissionsForPrincipal(prin1)
         self.assertEqual(len(perms), 2)
-        self.failUnless((perm1, Allow) in perms)
-        self.failUnless((perm2, Allow) in perms)
+        self.assertTrue((perm1, Allow) in perms)
+        self.assertTrue((perm2, Allow) in perms)
         manager.denyPermissionToPrincipal(perm2, prin1)
         perms = manager.getPermissionsForPrincipal(prin1)
         self.assertEqual(len(perms), 2)
-        self.failUnless((perm1, Allow) in perms)
-        self.failUnless((perm2, Deny) in perms)
+        self.assertTrue((perm1, Allow) in perms)
+        self.assertTrue((perm2, Deny) in perms)
 
     def testManyPrincipalsOnePermission(self):
         manager = AnnotationPrincipalPermissionManager(Manageable())
         provideUtility(Permission('Perm One', 'title'), IPermission,
                        'Perm One')
-        perm1 = 'Perm One' 
+        perm1 = 'Perm One'
         prin1 = self._make_principal()
         prin2 = self._make_principal('Principal 2', 'Principal Two')
         manager.grantPermissionToPrincipal(perm1, prin1)
         manager.denyPermissionToPrincipal(perm1, prin2)
         principals = manager.getPrincipalsForPermission(perm1)
         self.assertEqual(len(principals), 2)
-        self.failUnless((prin1, Allow) in principals)
-        self.failUnless((prin2, Deny) in principals)
+        self.assertTrue((prin1, Allow) in principals)
+        self.assertTrue((prin2, Deny) in principals)
+
 
 def test_suite():
-    loader=unittest.TestLoader()
+    loader = unittest.TestLoader()
     return loader.loadTestsFromTestCase(Test)
 
-if __name__=='__main__':
+if __name__ == '__main__':
     unittest.TextTestRunner().run(test_suite())
