@@ -15,7 +15,7 @@
 """
 import unittest
 import zope.component
-from zope.interface import implements
+from zope.interface import implementer
 from zope.annotation.interfaces import IAttributeAnnotatable
 
 from zope.component.testing import PlacelessSetup
@@ -27,16 +27,20 @@ from zope.securitypolicy.interfaces import IRole
 from zope.securitypolicy.role import Role
 from zope.securitypolicy.tests import principalRegistry
 
+
+@implementer(IAttributeAnnotatable)
 class Manageable(object):
-    implements(IAttributeAnnotatable)
+    pass
+
 
 def defineRole(id, title=None, description=None):
     role = Role(id, title, description)
     zope.component.provideUtility(role, IRole, name=role.id)
     return role
 
+
 class Test(PlacelessSetup, unittest.TestCase):
-    
+
     def setUp(self):
         PlacelessSetup.setUp(self)
         zope.component.provideAdapter(AttributeAnnotations)
@@ -105,8 +109,8 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role2, prin1)
         roles = principalRoleManager.getRolesForPrincipal(prin1)
         self.assertEqual(len(roles), 2)
-        self.failUnless((role1, Allow) in roles)
-        self.failUnless((role2, Allow) in roles)
+        self.assertTrue((role1, Allow) in roles)
+        self.assertTrue((role2, Allow) in roles)
 
     def testManyPrincipalsOneRole(self):
         principalRoleManager = self._make_roleManager()
@@ -117,8 +121,8 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role1, prin2)
         principals = principalRoleManager.getPrincipalsForRole(role1)
         self.assertEqual(len(principals), 2)
-        self.failUnless((prin1, Allow) in principals)
-        self.failUnless((prin2, Allow) in principals)
+        self.assertTrue((prin1, Allow) in principals)
+        self.assertTrue((prin2, Allow) in principals)
 
     def testPrincipalsAndRoles(self):
         principalRoleManager = self._make_roleManager()
@@ -133,13 +137,14 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role2, prin1)
         principalsAndRoles = principalRoleManager.getPrincipalsAndRoles()
         self.assertEqual(len(principalsAndRoles), 3)
-        self.failUnless((role1, prin1, Allow) in principalsAndRoles)
-        self.failUnless((role1, prin2, Allow) in principalsAndRoles)
-        self.failUnless((role2, prin1, Allow) in principalsAndRoles)
+        self.assertTrue((role1, prin1, Allow) in principalsAndRoles)
+        self.assertTrue((role1, prin2, Allow) in principalsAndRoles)
+        self.assertTrue((role2, prin1, Allow) in principalsAndRoles)
+
 
 def test_suite():
-    loader=unittest.TestLoader()
+    loader = unittest.TestLoader()
     return loader.loadTestsFromTestCase(Test)
 
-if __name__=='__main__':
+if __name__ == '__main__':
     unittest.TextTestRunner().run(test_suite())
