@@ -26,11 +26,13 @@ from zope.securitypolicy.interfaces import IRole
 from zope.securitypolicy.principalrole import principalRoleManager
 from zope.securitypolicy.tests import principalRegistry
 
+
 def defineRole(id, title=None, description=None):
     role = Role(id, title, description)
     provideUtility(role, IRole, role.id)
     return role
 
+
 class Test(PlacelessSetup, unittest.TestCase):
 
     def setUp(self):
@@ -82,8 +84,6 @@ class Test(PlacelessSetup, unittest.TestCase):
         self.assertEqual(principalRoleManager.getSetting(principal, role, 1),
                          1)
 
-
-
     def test_invalidPrincipal(self):
         self.assertRaises(ValueError,
                           principalRoleManager.assignRoleToPrincipal,
@@ -99,7 +99,6 @@ class Test(PlacelessSetup, unittest.TestCase):
                           principalRoleManager.assignRoleToPrincipal,
                           'role1', prin1)
 
-
     def testManyRolesOnePrincipal(self):
         role1 = defineRole('Role One', 'Role #1').id
         role2 = defineRole('Role Two', 'Role #2').id
@@ -108,8 +107,8 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role2, prin1)
         roles = principalRoleManager.getRolesForPrincipal(prin1)
         self.assertEqual(len(roles), 2)
-        self.failUnless((role1, Allow) in roles)
-        self.failUnless((role2, Allow) in roles)
+        self.assertTrue((role1, Allow) in roles)
+        self.assertTrue((role2, Allow) in roles)
 
     def testManyPrincipalsOneRole(self):
         role1 = defineRole('Role One', 'Role #1').id
@@ -119,8 +118,8 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role1, prin2)
         principals = principalRoleManager.getPrincipalsForRole(role1)
         self.assertEqual(len(principals), 2)
-        self.failUnless((prin1, Allow) in principals)
-        self.failUnless((prin2, Allow) in principals)
+        self.assertTrue((prin1, Allow) in principals)
+        self.assertTrue((prin2, Allow) in principals)
 
     def testPrincipalsAndRoles(self):
         role1 = defineRole('Role One', 'Role #1').id
@@ -132,14 +131,14 @@ class Test(PlacelessSetup, unittest.TestCase):
         principalRoleManager.assignRoleToPrincipal(role2, prin1)
         principalsAndRoles = principalRoleManager.getPrincipalsAndRoles()
         self.assertEqual(len(principalsAndRoles), 3)
-        self.failUnless((role1, prin1, Allow) in principalsAndRoles)
-        self.failUnless((role1, prin2, Allow) in principalsAndRoles)
-        self.failUnless((role2, prin1, Allow) in principalsAndRoles)
+        self.assertTrue((role1, prin1, Allow) in principalsAndRoles)
+        self.assertTrue((role1, prin2, Allow) in principalsAndRoles)
+        self.assertTrue((role2, prin1, Allow) in principalsAndRoles)
 
 
 def test_suite():
-    loader=unittest.TestLoader()
+    loader = unittest.TestLoader()
     return loader.loadTestsFromTestCase(Test)
 
-if __name__=='__main__':
+if __name__ == '__main__':
     unittest.TextTestRunner().run(test_suite())
