@@ -16,11 +16,13 @@
 from doctest import DocTestSuite
 import unittest
 
+from zope.securitypolicy import testing
+
 
 def test_suite():
     return unittest.TestSuite((
-        DocTestSuite('zope.securitypolicy.role'),
-        ))
+        DocTestSuite('zope.securitypolicy.role', checker=testing.checker),
+    ))
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
