@@ -14,26 +14,33 @@
 """Security Settings Tests
 """
 import unittest
-from cPickle import Pickler, Unpickler
-from StringIO import StringIO
+from pickle import Pickler, Unpickler
+
+try:
+    from StringIO import StringIO as BytesIO
+except ImportError:
+    # Py3: New location.
+    from io import BytesIO
 
 from zope.securitypolicy.interfaces import Allow
 
+
 class Test(unittest.TestCase):
 
     def testPickleUnpickle(self):
-        s = StringIO()
+        s = BytesIO()
         p = Pickler(s)
         p.dump(Allow)
         s.seek(0)
         u = Unpickler(s)
         newAllow = u.load()
 
-        self.failUnless(newAllow is Allow)
+        self.assertTrue(newAllow is Allow)
+
 
 def test_suite():
-    loader=unittest.TestLoader()
+    loader = unittest.TestLoader()
     return loader.loadTestsFromTestCase(Test)
 
-if __name__=='__main__':
+if __name__ == '__main__':
     unittest.TextTestRunner().run(test_suite())
