@@ -16,10 +16,14 @@
 from doctest import DocTestSuite
 import unittest
 
+from zope.securitypolicy import testing
+
+
 def test_suite():
     return unittest.TestSuite((
-        DocTestSuite('zope.securitypolicy.vocabulary'),
-        ))
+        DocTestSuite(
+            'zope.securitypolicy.vocabulary', checker=testing.checker),
+    ))
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
